#include <cstdlib>
#include <ctime>
#include <cmath>
#include <vector>
#include <fstream>
#include <iostream>
#include <direct.h>

#include "opencvpath.h"


//-----------------------------------------------------------
// parameter setting
const int NUMMKS = 5;		// number of markers
const int MARKERW = 900;	// marker width (pixel)
const int MARKERH = 900;	// marker height (pixel)
const int RAD = 8;			// circle radius (pixel)
const int NUMDTS = 40;		// number of dots
const int MARGIN = 40;		// minimum margin between points
//-----------------------------------------------------------


int main(int argc, char **argv)
{
	_mkdir("data");
	srand((unsigned) time(NULL));

	struct pt
	{
		int ux, uy;	// origin at upper left for making image file
		int lx, ly;	// origin at left lower for output text file
	};
	std::vector<pt> pts;

	pts.resize(NUMDTS);	// allocate array for points
	
	IplImage *img = cvCreateImage(cvSize(MARKERW, MARKERH),8,3);

	for(int h=0;h<NUMMKS;h++){		// for each marker

		for(int i=0;i<NUMDTS;i++){	// put points

			int x = rand() % (MARKERW-2*MARGIN) + MARGIN;
			int y = rand() % (MARKERH-2*MARGIN) + MARGIN;

			pts[i].lx = x;
			pts[i].ly = y;
			pts[i].ux = pts[i].lx;
			pts[i].uy = MARKERH - pts[i].ly;

			for(int j=0;j<i;j++){	// avoid overlap of dots
				float diff = sqrt((float)((x-pts[j].lx)*(x-pts[j].lx)+(y-pts[j].ly)*(y-pts[j].ly)));
				if(diff < (float)MARGIN){
					i--;
					break;
				}
			}
		}

		// output image file
		cvSetZero(img);
		cvNot(img, img);

		for(int i=0;i<NUMDTS;i++){
			cvCircle(img, cvPoint(pts[i].ux, pts[i].uy), RAD, CV_RGB(0,0,0), -1);
		}
		
		char name[256];
		sprintf_s(name,sizeof(name),"./data/%d.jpg",h);
		std::cout << name << " ";

		cvSaveImage(name, img);
		
		// output text file
		sprintf_s(name,sizeof(name),"./data/%d.txt",h);
		std::cout << name << std::endl;

		std::ofstream out(name);
		out << NUMDTS << std::endl;
		for(int i=0;i<NUMDTS;i++){
			out << pts[i].lx << " " << pts[i].ly << std::endl;
		}
		out.close();		
	}

	cvReleaseImage(&img);

	return 0;
}

